@@ -43,7 +43,11 @@ def get_ws_config_file_path(ws_dir: Path) -> Path:
     logger.debug(f"searching {ws_workspace_dir}")
     if ws_workspace_dir.exists() and ws_workspace_dir.is_dir():
         ws_config_file = ws_workspace_dir.joinpath("config.py")
-        if ws_config_file is not None and ws_config_file.exists() and ws_config_file.is_file():
+        if (
+            ws_config_file is not None
+            and ws_config_file.exists()
+            and ws_config_file.is_file()
+        ):
             return ws_config_file
 
     # Case 2: Look for a folder with name: data/workspace
@@ -54,7 +58,11 @@ def get_ws_config_file_path(ws_dir: Path) -> Path:
         logger.debug(f"searching {ws_data_workspace_dir}")
         if ws_data_workspace_dir.exists() and ws_data_workspace_dir.is_dir():
             ws_config_file = ws_data_workspace_dir.joinpath("config.py")
-            if ws_config_file is not None and ws_config_file.exists() and ws_config_file.is_file():
+            if (
+                ws_config_file is not None
+                and ws_config_file.exists()
+                and ws_config_file.is_file()
+            ):
                 return ws_config_file
 
     # Case 3: Look for a folder defined by the pyproject.toml file
@@ -66,7 +74,11 @@ def get_ws_config_file_path(ws_dir: Path) -> Path:
         logger.debug(f"searching {ws_name_workspace_dir}")
         if ws_name_workspace_dir.exists() and ws_name_workspace_dir.is_dir():
             ws_config_file = ws_name_workspace_dir.joinpath("config.py")
-            if ws_config_file is not None and ws_config_file.exists() and ws_config_file.is_file():
+            if (
+                ws_config_file is not None
+                and ws_config_file.exists()
+                and ws_config_file.is_file()
+            ):
                 return ws_config_file
 
     # Case 3: Look for a folder defined by the pyproject.toml file
@@ -77,9 +89,16 @@ def get_ws_config_file_path(ws_dir: Path) -> Path:
             phidat_conf_workspace_dir_str = phidata_conf.get("workspace", None)
             phidat_conf_workspace_dir = ws_dir.joinpath(phidat_conf_workspace_dir_str)
             logger.debug(f"searching {phidat_conf_workspace_dir}")
-            if phidat_conf_workspace_dir.exists() and phidat_conf_workspace_dir.is_dir():
+            if (
+                phidat_conf_workspace_dir.exists()
+                and phidat_conf_workspace_dir.is_dir()
+            ):
                 ws_config_file = phidat_conf_workspace_dir.joinpath("config.py")
-                if ws_config_file is not None and ws_config_file.exists() and ws_config_file.is_file():
+                if (
+                    ws_config_file is not None
+                    and ws_config_file.exists()
+                    and ws_config_file.is_file()
+                ):
                     return ws_config_file
 
     print_error(f"Could not find a workspace/config.py for {ws_dir}")
